@@ -6,8 +6,6 @@
 
 
 SEXP R_sc_multvec(SEXP p, SEXP x){
-   PROTECT(p);
-   PROTECT(x);
 
    SparseConstraints *xp = R_ExternalPtrAddr(p);
 
@@ -16,15 +14,13 @@ SEXP R_sc_multvec(SEXP p, SEXP x){
    
    sc_multvec(xp, REAL(x), REAL(Ax));
 
-   UNPROTECT(3);
+   UNPROTECT(1);
    return Ax;
 
 }
 
 
 SEXP R_sc_diffvec(SEXP p, SEXP x){
-   PROTECT(p);
-   PROTECT(x);
    SparseConstraints *xp = R_ExternalPtrAddr(p);
 
    SEXP dv;
@@ -32,22 +28,20 @@ SEXP R_sc_diffvec(SEXP p, SEXP x){
 
    sc_diffvec(xp, REAL(x), REAL(dv));
 
-   UNPROTECT(3);
+   UNPROTECT(1);
    return dv;
 
 }
 
 SEXP R_sc_diffmax(SEXP p, SEXP x){
 
-   PROTECT(p);
-   PROTECT(x);
    SparseConstraints *xp = R_ExternalPtrAddr(p);
 
    SEXP d;
    PROTECT(d = allocVector(REALSXP,1));
 
    REAL(d)[0] = sc_diffmax( xp, REAL(x) );
-   UNPROTECT(3);
+   UNPROTECT(1);
 
    return d;
 
@@ -55,15 +49,13 @@ SEXP R_sc_diffmax(SEXP p, SEXP x){
 
 SEXP R_sc_diffsum(SEXP p, SEXP x){
 
-   PROTECT(p);
-   PROTECT(x);
    SparseConstraints *xp = R_ExternalPtrAddr(p);
 
    SEXP d;
    PROTECT(d = allocVector(REALSXP,1));
 
    REAL(d)[0] = sc_diffsum( xp, REAL(x) );
-   UNPROTECT(3);
+   UNPROTECT(1);
 
    return d;
 
